/*
 * Copyright 2011-2012 Jiří Janoušek <janousek.jiri@gmail.com>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met: 
 * 
 * 1. Redistributions of source code must retain the above copyright notice, this
 *    list of conditions and the following disclaimer. 
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution. 
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR
 * ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#if EXPERIMENTAL

using Diorite.Logger;

namespace Nuvola.Extensions.Sample{
const string UI_SPEC = """
<ui>
	<menubar action="menubar">
		<menu action="service">
			<menuitem action="sample" />
		</menu>
	</menubar>
</ui>
""";

public Nuvola.ExtensionInfo get_info(){
	return {
		/// Name of a sample plugin
		_("Sample plugin"),
		"2.7182818284...",
		/// Sample plugin descriptiom
		_("<p>This plugin is a sample.</p>"),
		"Jiří Janoušek",
		typeof(Extension),
		false
	};
}


/**
 * Simple sample plugin
 */
public class Extension:  Nuvola.Extension{
	private weak Nuvola.Player player;
	private uint ui_merge_id = 0;
	private Diorite.Actions actions;
	
	/**
	 * {@inheritDoc}
	 */
	public override void load(ObjectContainer objects) throws ExtensionError{
		debug("[%s] load", id);
		// Get dependencies, throws ExtensionError
		player = objects.get<Player>("player");
		actions = objects.get<Diorite.Actions>("actions");
		var action = new Diorite.NormalAction("sample", Gtk.Stock.INFO, _("Sample Plugin MenuItem"), null, null, () => {
			debug("[%s] action activated", id);
		});
		actions.add_action(action);
	}
	
	/**
	 * {@inheritDoc}
	 */
	public override void add_actions_ui(Gtk.UIManager manager){
		debug("[%s] add_ui", id);
		try{
			ui_merge_id = manager.add_ui_from_string(UI_SPEC, UI_SPEC.length);
		}
		catch(GLib.Error e){
			warning("[%s] Unable to add ui: %s", id, e.message);
		}
	}
	
	/**
	 * {@inheritDoc}
	 */
	public override void remove_actions_ui(Gtk.UIManager manager){
		debug("[%s] remove_ui", id);
		if(ui_merge_id != 0){
			manager.remove_ui(ui_merge_id);
			ui_merge_id = 0;
		}
	}
	
	/**
	 * {@inheritDoc}
	 */
	public override void unload(){
		debug("[%s] unload", id);
	}
}

} // namespace Nuvola.Extensions.Sample
#endif
