/*
 * Copyright 2011-2012 Jiří Janoušek <janousek.jiri@gmail.com>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met: 
 * 
 * 1. Redistributions of source code must retain the above copyright notice, this
 *    list of conditions and the following disclaimer. 
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution. 
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR
 * ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

/* Anonymous function is used not to pollute environment */
(function(Nuvola){
var _ = Nuvola.gettext;
var startsWith = function(text, prefix){
	return text.substring(0, prefix.length) === prefix;
}

Nuvola.updateAction("prev", true);

if(window._is_service_page === true){
	if(startsWith(Nuvola.config.home_page, "http://") || startsWith(Nuvola.config.home_page, "https://")){
		window.location = Nuvola.config.home_page;
	}
	else{
		var notice = document.getElementById("notice");
		notice.appendChild(Nuvola.makeButton(_("Open service configuration"), function(){
			Nuvola.triggerAction("service-settings");
		}));
	}
}

// Let's play with classes

var Vehicle = Nuvola.makeClass(null, {
	$init: function(color){
		this.color = color;
		this.speed = 0;
		this.type = "vehicle";
	},
	
	changeSpeed: function(change){
		this.speed += change;
	},
	
	print: function(message){
		console.log("Hello, the " + this.color + " " + this.type +
			" has speed " + this.speed + " kmph" + (message || "") + "."); 
	}
});

var WindowHandler = {
	openWindow: function(){
		if(this.windowOpened !== true){
			this.windowOpened = true;
			console.log("Window has been opened.");
		}
	},
	
	closeWindow: function(){
		if(this.windowOpened === true){
			this.windowOpened = false;
			console.log("Window has been closed.");
		}
	}
}

var Car = Nuvola.makeClass([Vehicle, WindowHandler], {
	$init: function(color, label){
		this.$parent.$init.call(this, color);
		this.label = label;
		this.type = "car";
		this.windowOpened = false;
	},
	
	print: function(message){
		this.$parent.print.call(this, ", label '" + this.label +
			"' and window " + (this.windowOpened ? "opened" : "closed")
			+ (message || ""));
	}
});

var vehicle = new Vehicle("red");
vehicle.print();
vehicle.changeSpeed(10);
vehicle.print();

var blue_car = new Car("blue", "Škoda");
blue_car.print();
blue_car.changeSpeed(10);
blue_car.openWindow();
blue_car.print();

// Immediately call the anonymous function with Nuvola JS API main object as an argument.
// Note that "this" is set to the Nuvola JS API main object.
})(this);
