/*
 * Copyright 2012 Jiří Janoušek <janousek.jiri@gmail.com>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met: 
 * 
 * 1. Redistributions of source code must retain the above copyright notice, this
 *    list of conditions and the following disclaimer. 
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution. 
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR
 * ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

/* Anonymous function is used not to pollute environment */
(function(Nuvola){
// Alias for gettext function, returns translated string
var _ = Nuvola.bind(Nuvola, Nuvola.gettext);
var form = Nuvola.getSettingsForm();

var makeEntry = function(name){
	return new Nuvola.Entry(name,
		Nuvola.config[name],
		function(){
			Nuvola.config[name] = this.value;
			Nuvola.saveConfig();
			form.showReloadNotice();
		}
	);
}

form.append(new Nuvola.Checkbox(_("Hide Google Bar"),
	Nuvola.config.googlebar !== true,
	function(){
		Nuvola.config.googlebar = this.checked ? false : true;
		Nuvola.saveConfig();
		form.showReloadNotice();
	}
));

form.append(new Nuvola.Checkbox(_("Hide everything"),
	Nuvola.config.everyhing === false,
	function(){
		Nuvola.config.everyhing = this.checked ? false : true;
		Nuvola.saveConfig();
		form.showReloadNotice();
	}
));

form.insert(1, new Nuvola.Entry(_("Name"),
	Nuvola.config.name,
	function(){
		Nuvola.config.name = this.value;
		Nuvola.saveConfig();
		form.showReloadNotice();
	}
));

form.insert(1, makeEntry("Surname"));
form.insert(2, makeEntry("Age"));
form.insert(-1, makeEntry("Scifi book"));

alert("Form created");
while(form.children[1]){
	form.remove(form.children[1]);
}
form.remove(form.children[0]);
alert("Entries removed");

form.append(new Nuvola.Checkbox(_("Hide Google Bar"),
	Nuvola.config.googlebar !== true,
	function(){
		Nuvola.config.googlebar = this.checked ? false : true;
		Nuvola.saveConfig();
		form.showReloadNotice();
	}
));

form.append(new Nuvola.Checkbox(_("Hide everything"),
	Nuvola.config.everyhing === false,
	function(){
		Nuvola.config.everyhing = this.checked ? false : true;
		Nuvola.saveConfig();
		form.showReloadNotice();
	}
));

form.insert(1, new Nuvola.Entry(_("Name"),
	Nuvola.config.name,
	function(){
		Nuvola.config.name = this.value;
		Nuvola.saveConfig();
		form.showReloadNotice();
	}
));

form.insert(1, makeEntry("Surname"));
form.insert(2, makeEntry("Age"));
form.insert(-1, makeEntry("Scifi book"));

form.reloadAction = "home";

form.append(new Nuvola.FormMessage("In order to use this service, you have to specify a location on your instance of MyService."));

form.append(new Nuvola.Entry(_("Service location:"),
	Nuvola.config.home_page || "http://nuvolaplayer.fenryxo.cz",
	function(){
		Nuvola.config.home_page = this.value;
		Nuvola.saveConfig();
		form.showReloadNotice();
	}
));

// Immediately call the anonymous function with Nuvola JS API main object as an argument.
// Note that "this" is set to the Nuvola JS API main object.
})(this);
