using Fenryxo.Test;
using Fenryxo.Logger;

class Fenryxo.ActionsTest: Fenryxo.Test.TestCase{
	private Gtk.UIManager ui_manager;
	private Actions actions;
	
	public override void set_up(){
		ui_manager = new Gtk.UIManager();
		actions = new Actions(ui_manager, "testname");
	}
	
	construct{
		add_task("add_action", test_add_action);
		add_task("add_actions", test_add_actions, {"add_action"});
		add_task("add_radio_actions", test_add_radio_actions, {"add_action"});
		add_task("get_action", test_get_action, {"add_action"});
		add_task("remove_action", test_remove_action, {"add_action", "get_action"});
	}
	
	public void test_add_action() throws TestError{
		var action1 = new NormalAction("help", "Help", null, "help", "F1");
		Assert.is_true(this.actions.add_action(action1), "Failed to add unique action");
		Assert.is_false(this.actions.add_action(action1), "Failed to refuse non-unique action");
		
		var action2 = new NormalAction("quit", "Quit", "Quit application", "exit", "<ctrl>Q");
		Assert.is_true(this.actions.add_action(action2), "Failed to add unique action");
		Assert.is_false(this.actions.add_action(action2), "Failed to refuse non-unique action");
		
	}
	
	public void test_add_actions() throws TestError{
		Action[] actions = {};
		actions += new NormalAction("help", "Help", null, "help", "F1");
		actions += new NormalAction("quit", "Quit", "Quit application", "exit", "<ctrl>Q");
		actions += new NormalAction("dinner", "Dinner", null, null, null);
		Assert.is_true(this.actions.add_actions(actions), "Failed to add unique actions");
		Assert.is_false(this.actions.add_actions(actions), "Failed to refuse non-unique actions");
		
		actions = {};
		actions += new NormalAction("help2", "Help", null, "help", "F1");
		actions += new NormalAction("quit2", "Quit", "Quit application", "exit", "<ctrl>Q");
		actions += new NormalAction("dinner2", "Dinner", null, null, null);
		Assert.is_true(this.actions.add_actions(actions), "Failed to add unique actions");
		Assert.is_false(this.actions.add_actions(actions), "Failed to refuse non-unique actions");
	}
	
	public void test_add_radio_actions() throws TestError{
		RadioAction[] actions = {};
		int current = 2;
		actions += new RadioAction("help", "Help", null, "help", "F1", 1);
		actions += new RadioAction("quit", "Quit", "Quit application", "exit", "<ctrl>Q", 2);
		actions += new RadioAction("dinner", "Dinner", null, null, null, 3);
		Assert.is_true(this.actions.add_radio_actions(actions, current), "Failed to add unique actions");
		
		Assert.cmp_int(actions[0].get_current_value(), "==", current);
		Assert.cmp_int(actions[1].current_value, "==", current);
		Assert.cmp_int(actions[2].current_value, "==", current);
		
		Assert.is_false(this.actions.add_radio_actions(actions, current + 1), "Failed to refuse non-unique actions");
		Assert.is_false(this.actions.add_actions((Action[])actions), "Failed to refuse non-unique actions");
	}
	
	public void test_get_action() throws TestError{
		var action1 = new NormalAction("help", "Help", null, "help", "F1");
		this.actions.add_action(action1);
		
		var response = actions.get_action(action1.name);
		Assert.not_null(response, "Failed to get action.");
		Assert.cmp_str(response.name, "==" , action1.name);
		
		response = actions.get_action("foo");
		Assert.is_null(response, "Action foo should not exist.");
	}
	
	public void test_remove_action() throws TestError{
		var action1 = new NormalAction("help", "Help", null, "help", "F1");
		this.actions.add_action(action1);
		
		Assert.is_true(this.actions.remove_action(action1.name), "Failed to remove action");
		Assert.is_null(actions.get_action(action1.name), "Action should not exist.");
		
		Assert.is_false(this.actions.remove_action(action1.name), "Action should not exist.");
		Assert.is_true(this.actions.add_action(action1), "Failed to add unique action #2");
	}
}
