using Fenryxo.Test;
using Fenryxo.Logger;

class Nuvola.PlayerTest: Fenryxo.Test.TestCase{
	private Nuvola.Storage storage;
	private DummyService? service;
	private Player? player;
	
	construct{
		add_task("commands", test_commands);
		add_task("song_changed", test_song_changed);
	}
	
	public override void set_up_before(){
		storage = new Storage(APPNAME + "/services");
	}
	
	public override void set_up(){
		player = new Player(null, storage);
		service = new DummyService();
	}
	
	public override void tear_down(){
		player = null;
	}
	
	public void test_commands() throws TestError{
		var service = new DummyService();
		player.service = service;
		
		Assert.is_true(service.cmd == null, "Last command is not null");
		
		foreach(var cmd in PlayerActions.all()){
			player.trigger_action(cmd, false);
			if(cmd == PlayerActions.QUIT){
				Assert.cmp_int(cmd, "!=", service.cmd);
			}
			else{
				Assert.cmp_int(cmd, "==", service.cmd);
			}
		}
	}
	
	public void test_song_changed() throws TestError{
		var service = new DummyService();
		player.service = service;
		
		var ctx = new AsyncContext();
		string? data[5] = new string[5];
		data[0] = "I love Vala";
		data[1] = "Jiří Janoušek";
		data[2] = "Best of";
		data[3] = "http:/goo";
		var state = STATE_PLAYING;
		
		ctx.handler_id = player.song_changed.connect((song, artist, album, art) => {
			try{
				Assert.cmp_str(song, "==", data[0]);
				Assert.cmp_str(artist, "==", data[1]);
				Assert.cmp_str(album, "==", data[2]);
				// TODO: test album art fetching
				Assert.cmp_str(art, "==", null);
				ctx.done();
			}
			catch(TestError e){
				ctx.fail(e);
			}
		});
		service.data_changed(data[0], data[1], data[2], data[3],
			state, true, false, true, false, true
		);
		Assert.cmp_str(player.playback_state, "==", state);
		Assert.cmp_int(player.actions, "==",
			PlayerActions.PAUSE | PlayerActions.PREV_SONG | PlayerActions.THUMBS_UP
			| PlayerActions.FAVORITE | PlayerActions.QUIT);
		ctx.assert_done("Signal song changed not emitted");
		
		data[0] = "C# is better";
		data[1] = "Microsoft";
		data[2] = null;
		data[3] = null;
		state = STATE_PAUSED;
		service.data_changed(data[0], data[1], data[2], data[3],
			state, false, true, false, true, false
		);
		Assert.cmp_str(player.playback_state, "==", state);
		Assert.cmp_int(player.actions, "==",
			PlayerActions.PLAY | PlayerActions.NEXT_SONG
			| PlayerActions.THUMBS_DOWN | PlayerActions.QUIT);
		ctx.assert_done("Signal song changed not emitted");
		player.disconnect(ctx.handler_id);
	}
}

class Nuvola.DummyService: GLib.Object, Nuvola.ServiceController{
	public PlayerActions? cmd = null;
	public void command(PlayerActions cmd) throws ServiceError{
		this.cmd = cmd;
	}
}


