using Fenryxo.Test;
using Fenryxo.Logger;

class Nuvola.ServiceSelectorViewTest: Fenryxo.Test.TestCase{
	private Storage storage;
	private ServicesManager manager;
	
	public override void set_up_before(){
		storage = new Storage(APPNAME + "/services");
		manager = new ServicesManager(storage);
	}
	
	construct{
		add_task("signals", test_signals);
	}
	
	public void test_signals() throws TestError{
		var window = new Gtk.Window();
		var view = new ServiceSelectorView(manager, true);
		window.add(view);
		
		var ctx = new AsyncContext();
		window.destroy.connect(ctx.interrupt);
		window.show_all();
		
		view.document_load_finished.connect(() => {
			view.execute_script("""
var triggerMouseEvent = function(elm, name){
    var event = document.createEvent('MouseEvents');
    event.initMouseEvent(name, true, true, document.defaultView, 1, 0, 0, 0, 0, false, false, false, false, 0, elm);
    elm.dispatchEvent(event);
}
var clickById = function(id){
	triggerMouseEvent(document.getElementById(id), "click");
}
""");
			ctx.done();
		});
		ctx.assert_timeout(5);
		
		
		view.canceled.connect(ctx.done);
		view.execute_script("""clickById("cancel");""");
		ctx.assert_timeout(1, "Selector not canceled");
		
		view.service_selected.connect((name) => {
			try{
				Assert.cmp_str(name, "==", "banana");
				ctx.done();
			}
			catch(TestError e){
				ctx.fail(e);
			}
		});
		view.execute_script("""clickById("service-banana");""");
		ctx.assert_timeout(1, "Service banana not selected");
		
		view.selector_shown.connect(ctx.done);
		view.refresh();
		ctx.assert_done("View refreshed");
		view.cancelable = false;
		ctx.assert_done("View cancelable changed refreshed view");
	}
}
