namespace Nuvola
{

private const string APP_CRASHED = "crashed";
private const string APP_CHECK_CRASHED = "check_crashed";
private const string LAST_SERVICE_KEY = "last_service";

private const string TMP_DIR = "build/tests/tmp";
public const string DATA_USER = "dirs/data_user";
public const string DATA_DIR_1 = "dirs/data_dir_1";
public const string DATA_DIR_2 = "dirs/data_dir_2";
public const string CONFIG_USER = "dirs/config_user";
public const string CACHE_USER = "dirs/cache_user";

// Top directory
public string TOP;

public void set_up_env(bool override_data_dirs=true)
{
	/* Set top directory */
	TOP = Environment.get_current_dir();
	if (TOP.has_suffix("tests/bin"))
		TOP = Path.get_dirname(Path.get_dirname(TOP));
	if (Path.get_basename(TOP) == "build")
		TOP = Path.get_dirname(TOP);
	/* Set XDG directories */
	Environment.set_variable("XDG_DATA_HOME", @"$TOP/$TMP_DIR/$DATA_USER", true);
	Environment.set_variable("XDG_CONFIG_HOME", @"$TOP/$TMP_DIR/$CONFIG_USER", true);
	Environment.set_variable("XDG_CACHE_HOME", @"$TOP/$TMP_DIR/$CACHE_USER", true);
	if (override_data_dirs)
		Environment.set_variable("XDG_DATA_DIRS", @"$TOP/$TMP_DIR/$DATA_DIR_1:$TOP/$TMP_DIR/$DATA_DIR_2", true);
	
	purge_test_dir();
}

public Diorite.Storage get_test_storage(string? subdir=null, string[]? extra_data_dirs=null)
{
	string root = TOP + "/" + TMP_DIR + "/";
	string[] data_dirs = {root + DATA_DIR_1, root + DATA_DIR_2};
	if (extra_data_dirs != null)
		foreach (var dir in extra_data_dirs)
			data_dirs += dir;
	
	var storage = new Diorite.Storage(root + DATA_USER,
		data_dirs,
		root + CONFIG_USER, root + CACHE_USER);
	return subdir == null ? storage : storage.get_child(subdir);
}

public File create_test_dir(string? subdir=null)
{
	var dir = File.new_for_path(TOP + "/" + TMP_DIR);
	if (subdir != null)
	{
		dir = dir.get_child(subdir);
	}
	
	if (!dir.query_exists())
	{
		try
		{
			dir.make_directory_with_parents();
		}
		catch(Error e)
		{
			error("Unable to create directory %s: %s", dir.get_path(), e.message);
		}
	}
	return dir;
}

public void purge_test_dir()
{
	var dir = File.new_for_path(TOP + "/" + TMP_DIR);
	Diorite.System.try_purge_dir(dir);
}

} // namespace Nuvola

[CCode(cheader_filename = "config.h")]
namespace Config
{
	[CCode(cname="G_LOG_DOMAIN")]
	public extern const string LOG_DOMAIN;
	[CCode(cname="GETTEXT_PACKAGE")]
	public extern const string GETTEXT_PACKAGE;
	[CCode(cname="LOCALES_DIR")]
	public extern const string LOCALES_DIR;
	public extern const string APPNAME;
	public extern const string DESKTOP_ENTRY;
	public extern const string UNIQUE_NAME;
	public extern const string APP_ICON;
	public extern const string DISPLAY_NAME;
	public extern const string VERSION;
	public extern const int VERSION_MAJOR;
	public extern const int VERSION_MINOR;
	public extern const int VERSION_BUGFIX;
	public extern const string VERSION_SUFFIX;
}
