
/* Anonymous function is used not to pollute environment */
(function(Nuvola){
	/**
	 * Creates Google Music integration binded to Nuvola JS API
	 * @param Nuvola Nuvola JS API
	 */
	var Integration = function(){
		/* Overwrite default commnad function */
		Nuvola.command = Nuvola.bind(this, this.command);
		
		/* For debug output */
		this.name = "Banana Radio";		
		
		/* Let's run */
		this.state = Nuvola.STATE_NONE;
		
		this.song = null;
		this.songs = [
			{
				name: "I love Vala",
				artist: "Jiří Janoušek",
				album: "Best of"
			},
			{
				name: "C is so ugly",
				artist: "Jiří Janoušek",
				album: "Best of"
			},
			{
				name: "C# is better",
				artist: "Microsoft",
				album: "Service Pack 99"
			}
		];
		this.pos =  -1;
		this.update();
	}
	
	Integration.prototype.toggle = function(){
		
		if(this.state == Nuvola.STATE_PLAYING){
			this.state = Nuvola.STATE_PAUSED;
		}
		else{
			this.state = Nuvola.STATE_PLAYING;
			if(this.pos < 0){
				this.pos = 0;
				this.song = this.songs[this.pos];
			}
		}
		
		this.update();
	}
	
	
	Integration.prototype.next = function(){
		if(this.pos < this.songs.length - 1){
			this.song = this.songs[++this.pos];
			this.update();
		}
	}
	
	Integration.prototype.prev = function(){
		if(this.pos > 0){
			this.song = this.songs[--this.pos];
			this.update();
		}
	}
	
	/**
	 * Updates current playback state
	 */
	Integration.prototype.update = function(){
		console.log("update");
		var album = null;
		var album_art = null;
		var artist = null;
		var song = null;
		var can_prev = this.pos > 0;
		var can_next = this.pos >= 0 && this.pos < this.songs.length -1;
		var can_thumbs_up = false;
		var can_thumbs_down = false;
		var can_favorite = false;
			
		try{
			artist = this.song.artist;
			song = this.song.name;
			album = this.song.album;
		}
		catch(e){
			//~ console.debug("Unable to obtain song info: " + e.message);
		}
		
		console.log("-update-");
		// Submit data to Nuvola backend
		Nuvola.dataChanged(
			song, artist, album, album_art,
			this.state, can_prev, can_next,
			can_thumbs_up, can_thumbs_down, can_favorite);
		console.log("/update");
	}
	
	/**
	 * Command handler
	 * @param cmd command to execute
	 */
	Integration.prototype.command = function(cmd){
		/* SJBpost is an internal Google Music JavaScript function */
		try{
			switch(cmd){
			case Nuvola.CMD_PLAY:
				if(this.state != Nuvola.STATE_PLAYING){
					this.toggle();
				}
				break;
			case Nuvola.CMD_PAUSE:
				if(this.state == Nuvola.STATE_PLAYING){
					this.toggle();
				}
				break;
			case Nuvola.CMD_TOGGLE:
				this.toggle();
				break;
			case Nuvola.CMD_PREV_SONG:
				this.prev();
				break;
			case Nuvola.CMD_NEXT_SONG:
				this.next();
				break;
			default:
				// Other commands are not supported
				throw {"message": "Not supported."};
			}
			console.log(this.name + ": comand '" + cmd + "' executed.");
		}
		catch(e){
			// API expects exception to be a string!
			throw (this.name + ": " + e.message);
		}
	}

	/* Store reference */ 
	Nuvola.integration = new Integration(); // Singleton

// Call anonymous function with Nuvola object as an argument
})(window._Nuvola);
