/*
 * Copyright 2012 Jiří Janoušek <janousek.jiri@gmail.com>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met: 
 * 
 * 1. Redistributions of source code must retain the above copyright notice, this
 *    list of conditions and the following disclaimer. 
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution. 
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR
 * ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
using FsoFramework.Test;

public class Diorite.SimpleDocViewTest: FsoFramework.Test.TestCase
{
	private SimpleDocBuffer? buffer = null;
	private const string DOC_BASIC = """
<h1>Heading 1</h1>
<h2>Heading 2</h2>

<p><a href="http://google.com"><b>Lorem ipsum</b> <i>dolor sit amet</i></a>, consetetur sadipscing elitr, sed diam
nonumyeirmod tempor invidunt ut labore et dolore magna aliquyam erat,
sed diamvoluptua. <b><i>At vero</i> eos</b> et accusam et justo duo dolores et
ea rebum. Stet clita kasd gubergren, no sea <a href="http://valadoc.org">takimata sanctus</a> est
Lorem ipsum dolor sit amet.</p>

<h2>Heading 2</h2>
<h3>Heading 3</h3>
<p><i><b>Lorem</b> ipsum</i> dolor<br/>sit amet,<br /> consetetur sadipscing elitr,
sed diam nonumyeirmod tempor invidunt ut labore et dolore
magna aliquyam erat, sed diamvoluptua. At vero eos et
accusam et justo duo dolores et ea reb.</p>

<p>
<img src="data://icons/hicolor/24x24/apps/nuvolaplayer.png" /> = image with natural width 24px<br/>
<img src="data://icons/hicolor/64x64/apps/nuvolaplayer.png" width="24" /> = image scaled from 64px to 24px
</p>
<p>
<img src="test://images/boxes_1234.svg" /><img src="test://images/boxes_5678.svg" />
</p>

<dl>
<dt>Name</dt>
<dd>Jiří Janoušek</dd>
<dt>Favorite colors</dt>
<dd><i>Blue</i></dd>
<dd>White</dd>
<dt>About</dt>
<dd><i><b>Lorem</b> ipsum</i> dolor sit amet, consetetur sadipscing elitr,
sed diam nonumyeirmod tempor invidunt ut labore et dolore
magna aliquyam erat, sed diamvoluptua. At vero eos et
accusam et justo duo dolores et ea reb.</dd>
</dl>

<ul>
<li><i><b>Lorem</b> ipsum</i> dolor sit amet, consetetur sadipscing elitr,
sed diam nonumyeirmod tempor invidunt ut labore et dolore
magna aliquyam erat, sed diamvoluptua. At vero eos et
accusam et justo duo dolores et ea reb.</li>
<li><i><b>Lorem</b> ipsum</i> dolor sit amet, consetetur sadipscing elitr,
sed diam nonumyeirmod tempor invidunt ut labore et dolore
magna aliquyam erat, sed diamvoluptua. At vero eos et
accusam et justo duo dolores et ea reb.</li>
<li><i><b>Lorem</b> ipsum</i> dolor sit amet, consetetur sadipscing elitr,
sed diam nonumyeirmod tempor invidunt ut labore et dolore
magna aliquyam erat, sed diamvoluptua. At vero eos et
accusam et justo duo dolores et ea reb.</li>
</ul>
""";
	private const string LINK_CLICKED_URIS = "http://google.com;http://valadoc.org;";
	private string link_clicked_uris = "";
	private const string IMAGE_CLICKED_PATHS = "boxes_1234.svg;boxes_1234.svg;boxes_1234.svg;boxes_1234.svg;boxes_5678.svg;boxes_5678.svg;boxes_5678.svg;boxes_5678.svg;";
	private string images_clicked_paths = "";
	private const string REQUESTED_IMAGES = "data://icons/hicolor/24x24/apps/nuvolaplayer.png;data://icons/hicolor/64x64/apps/nuvolaplayer.png;test://images/boxes_1234.svg;test://images/boxes_5678.svg;";
	private string requested_images;
	
	public SimpleDocViewTest()
	{
		base("Diorite.SimpleDocBufferTest");
		add_test("normal_view", test_normal_view);
		add_test("simpledocview", test_simpledocview);
	}
	
	
	public override void set_up()
	{
		buffer = new SimpleDocBuffer();
		buffer.image_locator = image_requested;
		requested_images = "";
	}
	
	public override void tear_down()
	{
		buffer = null;
	}
	
	private void assert_properly_rendered(Gtk.TextView view, string doc_body, string? message=null)
	{
		var code = message != null ? "<p>%s</p>\n%s".printf(message, doc_body) : doc_body;
		try
		{
			
			buffer.load(code);
			
		}
		catch(MarkupError e)
		{
			assert_not_reached();
		}
		
		var dialog = new Gtk.Dialog();
		var box = new Gtk.Box(Gtk.Orientation.HORIZONTAL, 5);
		dialog.get_content_area().add(box);
		dialog.add_button(Gtk.Stock.YES, Gtk.ResponseType.YES);
		dialog.add_button(Gtk.Stock.NO, Gtk.ResponseType.NO);
		dialog.title = "Is the code rendered properly?";
		
		var scroll = new Gtk.ScrolledWindow(null, null);
		var source = new Gtk.TextView();
		source.buffer.set_text(code);
		source.wrap_mode = Gtk.WrapMode.WORD_CHAR;
		scroll.set_size_request(400, 400);
		scroll.add(source);
		box.add(scroll);
		
		scroll = new Gtk.ScrolledWindow(null, null);
		scroll.set_size_request(400, 400);
		view.wrap_mode = Gtk.WrapMode.WORD_CHAR;
		scroll.add(view);
		box.add(scroll);
		
		box.show_all();
		var response = dialog.run();
		dialog.destroy();
		assert(response == Gtk.ResponseType.YES);
	}
		
	public void test_normal_view()
	{
		buffer.link_color = {1.0, 0.0, 0.0, 1.0};
		var view = new Gtk.TextView.with_buffer(buffer);
		assert_properly_rendered(view, DOC_BASIC, "Link color must be red.");
		assert(requested_images == REQUESTED_IMAGES);
	}
	
	public void test_simpledocview()
	{
		var view = new SimpleDocView(buffer);
		view.border_width = 25;
		view.link_opener = link_clicked;
		view.image_opener = image_clicked;
		assert_properly_rendered(view, DOC_BASIC, "Link color must have theme color and must change cursor. Click to each link in natural order. Click color boxes 1-8 in a numeric order.");
		assert(link_clicked_uris == LINK_CLICKED_URIS);
		assert(requested_images == REQUESTED_IMAGES);
		assert(images_clicked_paths == IMAGE_CLICKED_PATHS);
	}
	
	private void link_clicked(string uri)
	{
		link_clicked_uris += uri + ";";
	}
	
	private void image_clicked(string path)
	{
		images_clicked_paths += Path.get_basename(path) + ";";
	}
	
	
	private string image_requested(string uri)
	{
		requested_images += uri + ";";
		if (uri.has_prefix("data://"))
			return Nuvola.TOP + "/build/data/" + uri.substring(7);
		if (uri.has_prefix("test://"))
			return Nuvola.TOP + "/tests/data/" + uri.substring(7);
		else
			return uri;
	}
}
