/*
 * Copyright 2012 Jiří Janoušek <janousek.jiri@gmail.com>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met: 
 * 
 * 1. Redistributions of source code must retain the above copyright notice, this
 *    list of conditions and the following disclaimer. 
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution. 
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR
 * ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
using FsoFramework.Test;
#if NOTIFICATIONS
public class Nuvola.Extensions.Notifications.ExtensionTest: FsoFramework.Test.TestCase{
	const string ARTIST = "Eva a Vašek";
	const string SONG = "Bílá orchidej?!\\";
	private Diorite.Storage? storage = null;
	private Gtk.Window? main_window = null;
	private ObjectContainer? objects = null;
	private Nuvola.Extensions.Notifications.Extension? notifier = null;
	private Diorite.Actions? actions = null;
	private Nuvola.MockPlayer? player = null;
	
	public ExtensionTest(){
		base("Nuvola.Extensions.Notifications.ExtensionTest");
		add_test("song_changes", test_song_changes);
		add_test("playback_controls", test_playback_controls);
	}
	
	
	public override void set_up(){
		var app = new Nuvola.MockApplication();
		actions = new Diorite.Actions(new Gtk.UIManager(), "nuvola");
		player = new Nuvola.MockPlayer(actions);
		var config = new Diorite.MultiTypeHashMap();
		
		main_window = new Gtk.Window();
		
		var objects = new HashTable<string, Object>(str_hash, str_equal);
		objects.insert("application", app);
		objects.insert("main_window", main_window);
		objects.insert("player", player);
		objects.insert("config", config);
		objects.insert("actions", actions);
		this.objects = new ObjectContainer(objects);
		
		notifier = new Nuvola.Extensions.Notifications.Extension();
		notifier.load(this.objects);
	}
	
	public override void tear_down(){
		main_window.destroy();
		main_window = null;
		objects = null;
		notifier = null;
		actions = null;
		player = null;
	}
	
	public void test_song_changes(){
		notifier.resident = true;
		var ih = new InteractiveHelper("""Five notifications for songs from #1 to 5# should be emitted with delay 1 second.""");
		int steps = 5;
		Timeout.add_seconds(1, () => {
			steps--;
			if (steps >= 0)
			{
				player.next_song();
				return true;
			}
			else
			{
				ih.done();
				return false;
			}
		});
		
		player.play();
		ih.run();
	}
	
	public void test_playback_controls(){
		notifier.resident = true;
		var ih = new InteractiveHelper("""A notification should appear. Test playback controls (play, pause, previous song, next song).""");
		player.play();
		ih.assert_ok();
	}

	
}
#endif
