namespace Nuvola{

int main(string[] args)
{
	set_up_env(false); // Gdk.Pixbuf loader requires original XDG_DATA_DIRS
	GLib.Test.log_set_fatal_handler(() => { return false; });
	Gtk.test_init(ref args);
	var selector = new InteractiveTestsSelector(TestSuite.get_root());
	
	#if NOTIFICATIONS
	selector.add_test_case(new Nuvola.Extensions.Notifications.ExtensionTest());
	#endif
	selector.add_test_case(new Diorite.SimpleDocViewTest());
	
	selector.run();
	selector.destroy();
	return Test.run();
}

public class InteractiveHelper
{
	private string message = null;
	private Gtk.MessageDialog? dialog = null;
	
	public InteractiveHelper(string message){
		this.message = message;
	}
	
	public void run()
	{
		dialog = new Gtk.MessageDialog(null, 0, Gtk.MessageType.INFO, 0,
			"A test has started.\n\n" + message);
		dialog.add_button("Interrupt", Gtk.ResponseType.REJECT);
		var response = dialog.run();
		dialog.destroy();
		dialog = null;
		assert(response == Gtk.ResponseType.OK);
		
		assert_ok();
	}
	
	public void assert_ok(){
		var assertion = new Gtk.MessageDialog(null, 0, Gtk.MessageType.QUESTION,
			Gtk.ButtonsType.YES_NO,
			message + "\n\nThe test has been finished. Was it successful?");
		
		var response = assertion.run();
		assertion.destroy();
		assert(response == Gtk.ResponseType.YES);
	}
	
	public void interrupt()
	{
		if (dialog != null)
		{
			dialog.response(Gtk.ResponseType.REJECT);
		}
	} 
	
	public void done()
	{
		if (dialog != null)
		{
			dialog.response(Gtk.ResponseType.OK);
		}
	}
}

private class InteractiveTestsSelector: Gtk.Dialog
{
	private weak TestSuite root_suite;
	
	public InteractiveTestsSelector(TestSuite root_suite)
	{
		this.root_suite = root_suite;
		title = "Interactive tests";
		add_button("Quit", 0);
		add_button("Run selected", 1);
		add_button("Run all", 2);
	}
	
	public void add_test_case(FsoFramework.Test.TestCase test_case)
	{
		var checkbox = new Gtk.CheckButton.with_label(test_case.get_type().name());
		checkbox.set_data<FsoFramework.Test.TestCase>("testcase", test_case);
		get_content_area().add(checkbox);
		checkbox.show();
	}
	
	public override void response(int response_id)
	{
		hide();
		while (Gtk.events_pending())
		{
			Gtk.main_iteration();
		}
		
		if (response_id == 1 || response_id == 2)
		{
			foreach (var child in get_content_area().get_children())
			{
				var checkbox = child as Gtk.CheckButton;
				if (checkbox != null && (response_id == 2 || checkbox.active))
				{
					var test_case = checkbox.steal_data<FsoFramework.Test.TestCase>("testcase");
					root_suite.add_suite(test_case.get_suite());
				}
			}
		}
	}
}

} // namespace Nuvola
