/*
 * Copyright 2012 Jiří Janoušek <janousek.jiri@gmail.com>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met: 
 * 
 * 1. Redistributions of source code must retain the above copyright notice, this
 *    list of conditions and the following disclaimer. 
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution. 
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR
 * ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
using FsoFramework.Test;

public class Diorite.SimpleDocBufferTest: FsoFramework.Test.TestCase
{
	private SimpleDocBuffer? buffer = null;
	
	public SimpleDocBufferTest()
	{
		base("Diorite.SimpleDocBufferTest");
		add_test("parse_errors", test_parse_errors);
		add_test("parse_basic", test_parse_basic);
		add_test("close_tag_from_stack", test_close_tag_from_stack);
	}
	
	
	public override void set_up()
	{
		buffer = new SimpleDocBuffer();
	}
	
	public override void tear_down()
	{
		buffer = null;
	}
	
	public void test_parse_errors()
	{
		try
		{
			buffer.load("""
<p><b>&</i></p>
""");
			assert_not_reached();
		}
		catch(MarkupError e){}
		
		try
		{
			buffer.load("""
<p><b</i></p>
""");
			assert_not_reached();
		}
		catch(MarkupError e){}
		
		try
		{
			buffer.load("""
<p><b></i></p>
""");
			assert_not_reached();
		}
		catch(MarkupError e){}
	}
	
	public void test_parse_basic()
	{
		try
		{
			buffer.load("""
<p><a href="http://google.com"><b>Lorem ipsum</b> <i>dolor sit amet</i></a>, consetetur sadipscing elitr, sed diam
nonumyeirmod tempor invidunt ut labore et dolore magna aliquyam erat,
sed diamvoluptua. <b><i>At vero</i> eos</b> et accusam et justo duo dolores et
ea rebum. Stet clita kasd gubergren, no sea <a href="http://valadoc.org">takimata sanctus</a> est
Lorem ipsum dolor sit amet.</p>

<p><i><b>Lorem</b> ipsum</i> dolor sit amet, consetetur sadipscing elitr,
sed diam nonumyeirmod tempor invidunt ut labore et dolore
magna aliquyam erat, sed diamvoluptua. At vero eos et
accusam et justo duo dolores et ea reb.</p>

<dl>
<dt>Name</dt>
<dd>Jiří Janoušek</dd>
<dt>Favorite colors</dt>
<dd><i>Blue</i></dd>
<dd>White</dd>
<dt>About</dt>
<dd><i><b>Lorem</b> ipsum</i> dolor sit amet, consetetur sadipscing elitr,
sed diam nonumyeirmod tempor invidunt ut labore et dolore
magna aliquyam erat, sed diamvoluptua. At vero eos et
accusam et justo duo dolores et ea reb.</dd>
</dl>
""");
			
		}
		catch(MarkupError e)
		{
			assert_not_reached();
		}
	}
	
	public void test_close_tag_from_stack()
	{
		try
		{
			buffer.load("""<p>""");
		}
		catch(MarkupError e)
		{
			assert_not_reached();
		}
		
		try
		{
			buffer.close_tag_from_stack("p");
		}
		catch(MarkupError e)
		{
			assert_not_reached();
		}
		
		try{
			buffer.close_tag_from_stack("p");
			assert_not_reached();
		}
		catch(MarkupError e){}
	}
}
