/*
 * Copyright 2012 Jiří Janoušek <janousek.jiri@gmail.com>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met: 
 * 
 * 1. Redistributions of source code must retain the above copyright notice, this
 *    list of conditions and the following disclaimer. 
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution. 
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR
 * ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
using FsoFramework.Test;

public class Nuvola.Extensions.Lyrics.CachedLyricsTest: FsoFramework.Test.TestCase{
	const string ARTIST = "Eva a Vašek";
	const string SONG = "Bílá orchidej?!\\";
	const string BLABOL = """
Úlevy obě u změny set patří obálky o staropanenské regál. V zámožné franka i šlapaje šachta? Tíž či tabule svědky ví nehýbat ježíšmárjá.

Nule svezl 213 vyrvat promešká 19 umí aeroplánem. Vylosovaný má 471 záruby zůstaňte za amino 11 závodě lues. Kupé stal zrazen brankář ukazuji.

Bera ni volá klekl, mihálička. Rys semnou flámu o ji samou roubal vzduchu slz milí odnést.

Ohmatávat prostějova krajan podroben: 411 tě spáchaná, osmý tužku víme nezasluhují souvislejší alimenty zadělávali šachy ó vlhké přivodil ponížení, supějících flámovat i fialový. Ocenit i túře teto poroty v babička mávl. Živ mírnost s řku k akta hoře loutka bums, slepý její ví po tě žádost bezmoc tě.

Klecí moři to dcera v slyšíte krákorající víru s zavraždil z česky. S krku hůř čestné výběr za až křup neduhy s váha míň 81 marné fuk vážná zády k vrhla tuto rozsvítil ženy ježatý spravuji oč zatímco mečel hlídat ex prodal nečetl pošleš že pšt baum.
""";
	private Diorite.Storage? storage = null;
	private CachedLyrics? cache = null;
	
	public CachedLyricsTest(){
		base("CachedLyricsTest");
		add_test("store", test_store);
		add_async_test("read",
			cb => test_read(cb),
			res => test_read.end(res),
			1000);
	}
	
	
	public override void set_up(){
		storage = get_test_storage();
		cache = new CachedLyrics(storage);
	}
	
	public override void tear_down(){
		storage = null;
		cache = null;
		purge_test_dir();
	}
	
	public void test_store(){
		assert("/tests/tmp/dirs/cache_user/" in storage.get_cache_path("test").get_path());
		cache.store(ARTIST, SONG, BLABOL);
		try{
			var text = Diorite.System.read_file(storage.get_cache_path("lyrics/eva a vašek/bílá orchidej,3F,21,5C.txt"));
			assert_cmpstr(text, Operator.EQ, BLABOL);
		}
		catch(GLib.Error e){
			assert_not_reached();
		}
	}
	
	public async void test_read() throws GLib.Error, AssertError{
		cache.store(ARTIST, SONG, BLABOL);
		var fetcher = cache as Fetcher;
		var text = yield fetcher.fetch_lyrics(ARTIST, SONG);
		assert_cmpstr(text, Operator.EQ, BLABOL);
	}
	
}

public class Nuvola.Extensions.Lyrics.AZLyricsTest: FsoFramework.Test.TestCase{
	public AZLyricsTest(){
		base("AZLyricsTest");
		add_test("transform_name", test_transform_name);
	}
	
	public void test_transform_name(){
		const string data[] = {
			"Michael Bublé", "michaelbuble",
			"Grown-Up Christmas List", "grownupchristmaslist"
		};
		for(var i = 0; i < data.length -1; i += 2){
			assert_cmpstr(AZLyrics.transform_name(data[i]), Operator.EQ, data[i+1]);
		}
	}
}
