namespace Nuvola
{

private GuiDemo? demo;

int main(string[] args)
{
	set_up_env(false); // Gdk.Pixbuf loader requires original XDG_DATA_DIRS
	Gtk.init(ref args);
	var selector = new UIDemoSelector();
	selector.add_demo(typeof(MainWindowTest));
	selector.add_demo(typeof(InfoBarDemo));
	selector.add_demo(typeof(WrappedLabelDemo));
	selector.add_demo(typeof(FormatSupportDialogDemo));
	selector.show_all();
	Gtk.main();
	return 0;
}

void on_demo_done()
{
	if (demo != null)
	{
		demo = null;
	}
}



void run_demo(Type type)
{
	var new_demo = Object.@new(type) as GuiDemo;
	if (new_demo != null)
	{
		if (demo != null)
		{
			demo.done.disconnect(on_demo_done);
			demo = null;
		}
		demo = new_demo;
		demo.done.connect_after(on_demo_done);
	}
}

abstract class GuiDemo: GLib.Object
{
	public signal void done();
}

private class UIDemoSelector: Gtk.Dialog
{
	public UIDemoSelector()
	{
		title = "UI Demo";
		add_button("Quit", 0);
	}
	
	public void add_demo(Type type)
	{
		var button = new Gtk.Button.with_label(type.name());
		button.set_data<Type>("demo_type", type);
		button.clicked.connect(on_button_clicked);
		get_content_area().add(button);
		button.show();
	}
	
	private void on_button_clicked(Gtk.Button button)
	{
		run_demo(button.get_data<Type>("demo_type"));
	}
	
	public override void response(int response_id)
	{
		Gtk.main_quit();
	}
}

} //namespace Nuvola
