#!/usr/bin/python3
# encoding: utf-8
#
# Copyright 2012 Jiří Janoušek <janousek.jiri@gmail.com>
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met: 
# 
# 1. Redistributions of source code must retain the above copyright notice, this
#    list of conditions and the following disclaimer. 
# 2. Redistributions in binary form must reproduce the above copyright notice,
#    this list of conditions and the following disclaimer in the documentation
#    and/or other materials provided with the distribution. 
# 
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
# ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
# DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR
# ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
# (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
# LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
# ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
# SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

TOP = "."

from copyrightdata import *
from optparse import OptionParser
import sys

parser = OptionParser()
parser.add_option("-f", "--file", dest="filename",
                  help="write report to FILE", metavar="FILE")
parser.add_option("-D", "--debian",
                  action="store_true", dest="debian", default=False,
                  help="Output in Debian copyright format")


import textwrap
SEPARATOR = "== License text =="
def debianize_text(text):
	mode = 0
	output = []
	for line in text.splitlines():
		if mode == 0:
			if SEPARATOR in line:
				mode = 1
		elif mode == 1:
			mode = 2
		elif line == "":
			output.append(" .\n")
		else:
			output += [" ", line, "\n"]

	return output


options, args = parser.parse_args()



output = []

if not options.debian:
	output.append(header)

	for section in copyright_info:
		output += ["\n"]
		try:
			items = section["files"]
			if isinstance(items, str):
				items = [items]
			output += ["Files:      ", "\n            ".join(items), "\n"]
		
			items = section["copyright"]
			if isinstance(items, str):
				items = [items]
			output += ["Copyright:  ", "\n            ".join(items), "\n"]
		
			license = licenses[section["license"]]
			output += ["License:    ", license["name"], "\nLegal text: See file ", license["file"], "\n"]
		except KeyError as e:
			print("Error: Missing key %s in\n%s" % (e, section))
			sys.exit(1)
else:
	output.append(header_debian)
	
	for section in copyright_info:
		output += ["\n"];
		items = section["files"]
		if isinstance(items, str):
			items = [items]
		output += ["Files: ", "\n       ".join(items), "\n"]
	
		items = section["copyright"]
		if isinstance(items, str):
			items = [items]
		output += ["Copyright: ", "\n           ".join(items), "\n"]
	
		license = licenses[section["license"]]
		output += ["License: ", license.get("debian_name", license["name"]), "\n"]
		
		try:
			output.append(license["debian_text"])
		except KeyError:
			with open(TOP + "/" + license["file"]) as f:
				output += debianize_text(f.read())


output = "".join(output)
print(output)
