#!/bin/bash

# Copyright 2011-2012 Jiří Janoušek <janousek.jiri@gmail.com>
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met: 
# 
# 1. Redistributions of source code must retain the above copyright notice, this
#    list of conditions and the following disclaimer. 
# 2. Redistributions in binary form must reproduce the above copyright notice,
#    this list of conditions and the following disclaimer in the documentation
#    and/or other materials provided with the distribution. 
# 
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
# ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
# DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR
# ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
# (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
# LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
# ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
# SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

#~ set -x

if [ -z "$1" ]; then
  echo "Usage:   `basename $0` SERVICE_DIR..."
  echo
  echo "         Creates service package (format 2) for Nuvola Player."
  echo
  echo "Example: `basename $0` data/nuvolaplayer/services/*"
  echo
  echo "         Creates packages for all services in given directory."
  exit 1
fi

WD=$PWD
RESULT=$WD

for SERVICE_DIR in "$@"; do

  cd "$WD"
  cd "$SERVICE_DIR"
  cd ..
  
  SERVICE=`basename "$SERVICE_DIR"`
  MAJOR=`grep -v version_minor "$SERVICE/metadata.conf" | grep version | cut -d '=' -f 2 | tr -d ' '`
  MINOR=`grep version_minor "$SERVICE/metadata.conf" | cut -d '=' -f 2 | tr -d ' '`
  NAME=`grep -v maintainer "$SERVICE/metadata.conf" | grep name | cut -d '=' -f 2`
  API_MAJOR=`grep api_major "$SERVICE/metadata.conf" | cut -d '=' -f 2 | tr -d ' '`
  API_MINOR=`grep api_minor "$SERVICE/metadata.conf" | cut -d '=' -f 2 | tr -d ' '`
  [ -z "$MINOR" ] && MINOR="0"
  [ -z "$API_MAJOR" ] && API_MAJOR="1" 
  [ -z "$API_MINOR" ] && API_MINOR="0" 
  TAR="$RESULT/nuvolaplayer--$SERVICE-$MAJOR.$MINOR.tar"
  
  echo "format = 2" > control
  echo "service_id = $SERVICE" >> control
  echo "
To install this service, select Switch Service from menu
and click on button Add at the bottom of service
selector screen. 
" > README
  echo $TAR:
  tar cvf $TAR $SERVICE control README
  rm -f control README
  gzip -9 -f $TAR
  echo
  cd "$WD"
  tools/package_db.py ../../service_updates_service \
  "$SERVICE" "$NAME" "$MAJOR.$MINOR" "$API_MAJOR.$API_MINOR" "$TAR.gz"
done
