#!/usr/bin/python3
# encoding: utf-8

import sys
import json
import os.path
import os
import shutil

APIS = [(2, 0), (2, 1), (2, 2)]

DB_FILE = "db.json"
packages_dir = sys.argv[1]
try:
	os.makedirs(packages_dir)
except Exception:
	pass

class Database:
	def __init__(self, root):
		self.root = root
		self.db_file = os.path.join(root, DB_FILE)
		self.load()
	
	def load(self):
		if os.path.exists(self.db_file):
			with open(self.db_file) as f:
				self.data = json.load(f)
		else:
			self.data = {}
		for api in APIS:
			key = "%d.%d" % api
			if not key in self.data:
				self.data[key] = {}
	
	def save(self):
		with open(self.db_file, "w") as f:
			json.dump(self.data, f, sort_keys=True, indent=4)
		for key, data in self.data.items():
			db_file = os.path.join(self.root, "api_%s.json" % key)
			with open(db_file, "w") as f:
				json.dump(data, f, sort_keys=True, indent=4)
	
	def add_package(self, id, version, api, name, package, changes):
		basename = os.path.basename(package)
		shutil.copy(package, self.root)
		os.remove(package)
		
		entry =  {
			"id": id,
			"version": version,
			"api": api,
			"name": name,
			"package": basename,
			"changes": changes,
		}
		api = api.split(".")
		api = (int(api[0]), int(api[1]))
		for api_level in APIS:
			if api_level >= api:
			 self.data["%d.%d" % api_level][id] = entry

id = sys.argv[2].strip()
name = sys.argv[3].strip()
version = sys.argv[4].strip()
api = sys.argv[5].strip()
package = sys.argv[6].strip()
changes = input("Changes for %s %s:\n" % (name, version)).strip()

db = Database(packages_dir)
db.add_package(id, version, api, name, package, changes)
db.save()

print("%s %s: %s" % (name, version, changes))
