#!/usr/bin/python3
# encoding: utf-8
#
# Copyright 2013 Jiří Janoušek <janousek.jiri@gmail.com>
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met: 
# 
# 1. Redistributions of source code must retain the above copyright notice, this
#    list of conditions and the following disclaimer. 
# 2. Redistributions in binary form must reproduce the above copyright notice,
#    this list of conditions and the following disclaimer in the documentation
#    and/or other materials provided with the distribution. 
# 
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
# ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
# DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR
# ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
# (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
# LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
# ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
# SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

import http.server
import socketserver
import time
import argparse

PORT = 1089

parser = argparse.ArgumentParser()
parser.add_argument('-p', '--port', type=int, default=PORT)
args = parser.parse_args()
port = args.port

class SlowDownloadHandler(http.server.BaseHTTPRequestHandler):
	def do_GET(self):
		try:
			size, duration, filename = self.path[1:].split("/")
			print("Sending", filename + ":", size, "MB in", duration, "seconds ...")
			size = int(size) * 1024
			duration = int(duration)
			self.send_response(200)
			self.send_header("Content-Type", "application/octet-stream")
			self.send_header("Content-Length", str(size))
			self.send_header("Content-Disposition", "attachment; filename=%s" % filename)
			self.send_header("Pragma", "no-cache" )
			self.end_headers()
			
			cursor = 0
			step = int(size / (2*duration - 1))
			chunk = ("A" * (step-1) + "\n").encode("ascii")
			while cursor < size:
				print(filename, cursor, "-", cursor + step)
				self.wfile.write(chunk[:size - cursor])
				self.wfile.flush()
				cursor += step
				try:
					time.sleep(0.5)
				except KeyboardInterrupt:
					pass
			print("Sending", filename, "... done!")
		except Exception as e:
			print(e)
			self.send_error(400)

class ThreadedTCPServer(socketserver.ThreadingMixIn, socketserver.TCPServer):
    pass
   
server = ThreadedTCPServer(("", port), SlowDownloadHandler)
print("Running slow download server on port", port)
try:
	server.serve_forever()
except KeyboardInterrupt:
	print("Shutdown.")
	server.shutdown()
except Exception as e:
	server.shutdown()
	raise e
